# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Commands.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Case_pb2 as Case__pb2
import Definitions_pb2 as Definitions__pb2
import PdmObject_pb2 as PdmObject__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Commands.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0e\x43ommands.proto\x12\x04rips\x1a\nCase.proto\x1a\x11\x44\x65\x66initions.proto\x1a\x0fPdmObject.proto\"1\n\x0f\x46ilePathRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x10\n\x08gridOnly\x18\x02 \x01(\x08\"9\n\x12ReplaceCaseRequest\x12\x13\n\x0bnewGridFile\x18\x01 \x01(\t\x12\x0e\n\x06\x63\x61seId\x18\x02 \x01(\x05\"B\n\x13ReplaceCaseRequests\x12+\n\tcasePairs\x18\x01 \x03(\x0b\x32\x18.rips.ReplaceCaseRequest\"F\n\x19ReplaceSourceCasesRequest\x12\x14\n\x0cgridListFile\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x61seGroupId\x18\x02 \x01(\x05\".\n\x16\x45xportMultiCaseRequest\x12\x14\n\x0cgridListFile\x18\x01 \x01(\t\"\xb2\x01\n\x16\x45xportSnapshotsRequest\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.rips.SnapshotType\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61seId\x18\x03 \x01(\x05\x12\x0e\n\x06viewId\x18\x04 \x01(\x05\x12\x14\n\x0c\x65xportFolder\x18\x05 \x01(\t\x12\x30\n\x10plotOutputFormat\x18\x06 \x01(\x0e\x32\x16.rips.PlotOutputFormat\"\x8f\x01\n\x15\x45xportPropertyRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08timeStep\x18\x02 \x01(\x05\x12\x10\n\x08property\x18\x03 \x01(\t\x12\x16\n\x0e\x65\x63lipseKeyword\x18\x04 \x01(\t\x12\x16\n\x0eundefinedValue\x18\x05 \x01(\x01\x12\x12\n\nexportFile\x18\x06 \x01(\t\"W\n\x1c\x45xportPropertyInViewsRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0f\n\x07viewIds\x18\x02 \x03(\x05\x12\x16\n\x0eundefinedValue\x18\x03 \x01(\x01\"\x8b\x03\n\x19\x45xportWellPathCompRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08timeStep\x18\x02 \x01(\x05\x12\x15\n\rwellPathNames\x18\x03 \x03(\t\x12+\n\tfileSplit\x18\x04 \x01(\x0e\x32\x18.rips.CompdatExportSplit\x12.\n\rcompdatExport\x18\x05 \x01(\x0e\x32\x17.rips.CompdatExportType\x12\x1b\n\x13includePerforations\x18\x06 \x01(\x08\x12\x18\n\x10includeFishbones\x18\x07 \x01(\x08\x12#\n\x1b\x65xcludeMainBoreForFishbones\x18\x08 \x01(\x08\x12\x35\n\x0f\x63ombinationMode\x18\t \x01(\x0e\x32\x1c.rips.CompdatCombinationMode\x12\x16\n\x0e\x63ustomFileName\x18\n \x01(\t\x12\x16\n\x0e\x65xportComments\x18\x0b \x01(\x08\x12\x15\n\rexportWelspec\x18\x0c \x01(\x08\"\xca\x01\n\x1c\x45xportSimWellPathFracRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x10\n\x08timeStep\x18\x03 \x01(\x05\x12\x1b\n\x13simulationWellNames\x18\x04 \x03(\t\x12+\n\tfileSplit\x18\x05 \x01(\x0e\x32\x18.rips.CompdatExportSplit\x12.\n\rcompdatExport\x18\x06 \x01(\x0e\x32\x17.rips.CompdatExportType\"4\n\x10\x45xportMswRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08wellPath\x18\x02 \x01(\t\"B\n\x15\x45xportWellPathRequest\x12\x15\n\rwellPathNames\x18\x01 \x03(\t\x12\x12\n\nmdStepSize\x18\x02 \x01(\x01\"\xaf\x01\n\x19\x45xportVisibleCellsRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x15\n\rexportKeyword\x18\x03 \x01(\t\x12\x1f\n\x17visibleActiveCellsValue\x18\x04 \x01(\x05\x12\x1e\n\x16hiddenActiveCellsValue\x18\x05 \x01(\x05\x12\x1a\n\x12inactiveCellsValue\x18\x06 \x01(\x05\"b\n\x16SetExportFolderRequest\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.rips.ExportFolderType\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0c\x63reateFolder\x18\x03 \x01(\x08\"7\n\x16RunOctaveScriptRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61seIds\x18\x02 \x03(\x05\"4\n\x13SetWindowSizeParams\x12\x0e\n\x06height\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\"C\n\x1b\x43omputeCaseGroupStatRequest\x12\x0f\n\x07\x63\x61seIds\x18\x01 \x03(\x05\x12\x13\n\x0b\x63\x61seGroupId\x18\x02 \x01(\x05\"E\n\x11SetTimeStepParams\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x10\n\x08timeStep\x18\x03 \x01(\x05\"N\n\x1cScaleFractureTemplateRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nhalfLength\x18\x02 \x01(\x01\x12\x0e\n\x06height\x18\x03 \x01(\x01\"L\n\x19SetFracContainmentRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08topLayer\x18\x02 \x01(\x05\x12\x11\n\tbaseLayer\x18\x03 \x01(\x05\"\xee\x01\n\x19\x43reateMultipleFracRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x12\n\ntemplateId\x18\x02 \x01(\x05\x12\x15\n\rwellPathNames\x18\x03 \x03(\t\x12\x19\n\x11minDistFromWellTd\x18\x04 \x01(\x01\x12\x1b\n\x13maxFracturesPerWell\x18\x05 \x01(\x05\x12\x10\n\x08topLayer\x18\x06 \x01(\x05\x12\x11\n\tbaseLayer\x18\x07 \x01(\x05\x12\x0f\n\x07spacing\x18\x08 \x01(\x05\x12(\n\x06\x61\x63tion\x18\t \x01(\x0e\x32\x18.rips.MultipleFracAction\"\xb8\x01\n\x17\x43reateLgrForCompRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08timeStep\x18\x02 \x01(\x05\x12\x15\n\rwellPathNames\x18\x03 \x03(\t\x12\x13\n\x0brefinementI\x18\x04 \x01(\x05\x12\x13\n\x0brefinementJ\x18\x05 \x01(\x05\x12\x13\n\x0brefinementK\x18\x06 \x01(\x05\x12%\n\tsplitType\x18\x07 \x01(\x0e\x32\x12.rips.LgrSplitType\",\n\x19\x43reateSatPressPlotRequest\x12\x0f\n\x07\x63\x61seIds\x18\x01 \x03(\x05\"/\n\x1a\x43reateGridCaseGroupRequest\x12\x11\n\tcasePaths\x18\x01 \x03(\t\"2\n\x1b\x43reateStatisticsCaseRequest\x12\x13\n\x0b\x63\x61seGroupId\x18\x01 \x01(\x05\"\xae\x01\n\x15\x45xportFlowInfoRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x11\n\ttimeSteps\x18\x02 \x03(\x05\x12\x11\n\tinjectors\x18\x03 \x03(\t\x12\x11\n\tproducers\x18\x04 \x03(\t\x12\x10\n\x08\x66ileName\x18\x05 \x01(\t\x12\x1c\n\x14minimumCommunication\x18\x06 \x01(\x01\x12\x1c\n\x14\x61quiferCellThreshold\x18\x07 \x01(\x01\"#\n\x11\x43reateViewRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\"\"\n\x10\x43loneViewRequest\x12\x0e\n\x06viewId\x18\x01 \x01(\x05\"r\n\x14\x43reateWbsPlotRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08wellPath\x18\x02 \x01(\t\x12\x10\n\x08timeStep\x18\x03 \x01(\x05\x12&\n\rwbsParameters\x18\x04 \x01(\x0b\x32\x0f.rips.PdmObject\"G\n\x16ImportWellPathsRequest\x12\x16\n\x0ewellPathFolder\x18\x01 \x01(\t\x12\x15\n\rwellPathFiles\x18\x02 \x03(\t\"H\n\x19ImportWellLogFilesRequest\x12\x15\n\rwellLogFolder\x18\x01 \x01(\t\x12\x14\n\x0cwellLogFiles\x18\x02 \x03(\t\"L\n\x1bImportFormationNamesRequest\x12\x16\n\x0e\x66ormationFiles\x18\x01 \x03(\t\x12\x15\n\rapplyToCaseId\x18\x02 \x01(\x05\"\xea\x01\n\x1c\x45xportWellLogPlotDataRequest\x12(\n\x0c\x65xportFormat\x18\x01 \x01(\x0e\x32\x12.rips.ExportFormat\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x14\n\x0c\x65xportFolder\x18\x03 \x01(\t\x12\x12\n\nfilePrefix\x18\x04 \x01(\t\x12\x14\n\x0c\x65xportTvdRkb\x18\x05 \x01(\x08\x12\x1b\n\x13\x63\x61pitalizeFileNames\x18\x06 \x01(\x08\x12\x18\n\x10resampleInterval\x18\x07 \x01(\x01\x12\x19\n\x11\x63onvertCurveUnits\x18\x08 \x01(\x08\"\xa4\x01\n\x1d\x45xportContourMapToTextRequest\x12\x16\n\x0e\x65xportFileName\x18\x01 \x01(\t\x12\x1e\n\x16\x65xportLocalCoordinates\x18\x02 \x01(\x08\x12\x1b\n\x13undefinedValueLabel\x18\x03 \x01(\t\x12\x1e\n\x16\x65xcludeUndefinedValues\x18\x04 \x01(\x08\x12\x0e\n\x06viewId\x18\x05 \x01(\x05\"&\n\x12SaveProjectRequest\x12\x10\n\x08\x66ilePath\x18\x01 \x01(\t\"\xb1\x12\n\rCommandParams\x12,\n\x0bopenProject\x18\x01 \x01(\x0b\x32\x15.rips.FilePathRequestH\x00\x12#\n\x0c\x63loseProject\x18\x02 \x01(\x0b\x32\x0b.rips.EmptyH\x00\x12,\n\x0bsetStartDir\x18\x03 \x01(\x0b\x32\x15.rips.FilePathRequestH\x00\x12)\n\x08loadCase\x18\x04 \x01(\x0b\x32\x15.rips.FilePathRequestH\x00\x12/\n\x0breplaceCase\x18\x05 \x01(\x0b\x32\x18.rips.ReplaceCaseRequestH\x00\x12=\n\x12replaceSourceCases\x18\x06 \x01(\x0b\x32\x1f.rips.ReplaceSourceCasesRequestH\x00\x12@\n\x18\x65xportMultiCaseSnapshots\x18\x07 \x01(\x0b\x32\x1c.rips.ExportMultiCaseRequestH\x00\x12\x37\n\x0f\x65xportSnapshots\x18\x08 \x01(\x0b\x32\x1c.rips.ExportSnapshotsRequestH\x00\x12\x35\n\x0e\x65xportProperty\x18\t \x01(\x0b\x32\x1b.rips.ExportPropertyRequestH\x00\x12\x43\n\x15\x65xportPropertyInViews\x18\n \x01(\x0b\x32\".rips.ExportPropertyInViewsRequestH\x00\x12\x44\n\x19\x65xportWellPathCompletions\x18\x0b \x01(\x0b\x32\x1f.rips.ExportWellPathCompRequestH\x00\x12N\n exportSimWellFractureCompletions\x18\x0c \x01(\x0b\x32\".rips.ExportSimWellPathFracRequestH\x00\x12+\n\texportMsw\x18\r \x01(\x0b\x32\x16.rips.ExportMswRequestH\x00\x12\x36\n\x0f\x65xportWellPaths\x18\x0e \x01(\x0b\x32\x1b.rips.ExportWellPathRequestH\x00\x12=\n\x12\x65xportVisibleCells\x18\x0f \x01(\x0b\x32\x1f.rips.ExportVisibleCellsRequestH\x00\x12\x37\n\x0fsetExportFolder\x18\x10 \x01(\x0b\x32\x1c.rips.SetExportFolderRequestH\x00\x12\x37\n\x0frunOctaveScript\x18\x11 \x01(\x0b\x32\x1c.rips.RunOctaveScriptRequestH\x00\x12\x36\n\x11setMainWindowSize\x18\x12 \x01(\x0b\x32\x19.rips.SetWindowSizeParamsH\x00\x12G\n\x1a\x63omputeCaseGroupStatistics\x18\x13 \x01(\x0b\x32!.rips.ComputeCaseGroupStatRequestH\x00\x12.\n\x0bsetTimeStep\x18\x14 \x01(\x0b\x32\x17.rips.SetTimeStepParamsH\x00\x12\x43\n\x15scaleFractureTemplate\x18\x15 \x01(\x0b\x32\".rips.ScaleFractureTemplateRequestH\x00\x12\x41\n\x16setFractureContainment\x18\x16 \x01(\x0b\x32\x1f.rips.SetFracContainmentRequestH\x00\x12\x42\n\x17\x63reateMultipleFractures\x18\x17 \x01(\x0b\x32\x1f.rips.CreateMultipleFracRequestH\x00\x12@\n\x17\x63reateLgrForCompletions\x18\x18 \x01(\x0b\x32\x1d.rips.CreateLgrForCompRequestH\x00\x12H\n\x1d\x63reateSaturationPressurePlots\x18\x19 \x01(\x0b\x32\x1f.rips.CreateSatPressPlotRequestH\x00\x12\x39\n\x14replaceMultipleCases\x18\x1a \x01(\x0b\x32\x19.rips.ReplaceCaseRequestsH\x00\x12?\n\x13\x63reateGridCaseGroup\x18\x1b \x01(\x0b\x32 .rips.CreateGridCaseGroupRequestH\x00\x12\x41\n\x14\x63reateStatisticsCase\x18\x1c \x01(\x0b\x32!.rips.CreateStatisticsCaseRequestH\x00\x12@\n\x19\x65xportFlowCharacteristics\x18\x1d \x01(\x0b\x32\x1b.rips.ExportFlowInfoRequestH\x00\x12-\n\ncreateView\x18\x1e \x01(\x0b\x32\x17.rips.CreateViewRequestH\x00\x12+\n\tcloneView\x18\x1f \x01(\x0b\x32\x16.rips.CloneViewRequestH\x00\x12\x41\n\x1b\x63reateWellBoreStabilityPlot\x18  \x01(\x0b\x32\x1a.rips.CreateWbsPlotRequestH\x00\x12\x37\n\x0fimportWellPaths\x18! \x01(\x0b\x32\x1c.rips.ImportWellPathsRequestH\x00\x12=\n\x12importWellLogFiles\x18\" \x01(\x0b\x32\x1f.rips.ImportWellLogFilesRequestH\x00\x12\x41\n\x14importFormationNames\x18# \x01(\x0b\x32!.rips.ImportFormationNamesRequestH\x00\x12\x43\n\x15\x65xportWellLogPlotData\x18$ \x01(\x0b\x32\".rips.ExportWellLogPlotDataRequestH\x00\x12\x36\n\x11setPlotWindowSize\x18% \x01(\x0b\x32\x19.rips.SetWindowSizeParamsH\x00\x12\x45\n\x16\x65xportContourMapToText\x18& \x01(\x0b\x32#.rips.ExportContourMapToTextRequestH\x00\x12/\n\x0bsaveProject\x18\' \x01(\x0b\x32\x18.rips.SaveProjectRequestH\x00\x42\x08\n\x06params\"9\n\x13GridCaseGroupResult\x12\x0f\n\x07groupId\x18\x01 \x01(\x05\x12\x11\n\tgroupName\x18\x02 \x01(\t\",\n\x1a\x43reateStatisticsCaseResult\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\"\"\n\x10\x43reateViewResult\x12\x0e\n\x06viewId\x18\x01 \x01(\x05\"%\n\x13\x43reateWbsPlotResult\x12\x0e\n\x06viewId\x18\x01 \x01(\x05\".\n\x15ImportWellPathsResult\x12\x15\n\rwellPathNames\x18\x01 \x03(\t\"1\n\x18ImportWellLogFilesResult\x12\x15\n\rwellPathNames\x18\x01 \x03(\t\"4\n\x1b\x45xportWellLogPlotDataResult\x12\x15\n\rexportedFiles\x18\x01 \x03(\t\"\xab\x04\n\x0c\x43ommandReply\x12\"\n\x0b\x65mptyResult\x18\x01 \x01(\x0b\x32\x0b.rips.EmptyH\x00\x12+\n\x0eloadCaseResult\x18\x02 \x01(\x0b\x32\x11.rips.CaseRequestH\x00\x12>\n\x19\x63reateGridCaseGroupResult\x18\x03 \x01(\x0b\x32\x19.rips.GridCaseGroupResultH\x00\x12\x46\n\x1a\x63reateStatisticsCaseResult\x18\x04 \x01(\x0b\x32 .rips.CreateStatisticsCaseResultH\x00\x12\x32\n\x10\x63reateViewResult\x18\x05 \x01(\x0b\x32\x16.rips.CreateViewResultH\x00\x12\x38\n\x13\x63reateWbsPlotResult\x18\x06 \x01(\x0b\x32\x19.rips.CreateWbsPlotResultH\x00\x12<\n\x15importWellPathsResult\x18\x07 \x01(\x0b\x32\x1b.rips.ImportWellPathsResultH\x00\x12\x42\n\x18importWellLogFilesResult\x18\x08 \x01(\x0b\x32\x1e.rips.ImportWellLogFilesResultH\x00\x12H\n\x1b\x65xportWellLogPlotDataResult\x18\t \x01(\x0b\x32!.rips.ExportWellLogPlotDataResultH\x00\x42\x08\n\x06result*$\n\x10PlotOutputFormat\x12\x07\n\x03PNG\x10\x00\x12\x07\n\x03PDF\x10\x01*-\n\x0cSnapshotType\x12\t\n\x05VIEWS\x10\x00\x12\t\n\x05PLOTS\x10\x01\x12\x07\n\x03\x41LL\x10\x02*`\n\x12\x43ompdatExportSplit\x12\x10\n\x0cUNIFIED_FILE\x10\x00\x12\x11\n\rSPLIT_ON_WELL\x10\x01\x12%\n!SPLIT_ON_WELL_AND_COMPLETION_TYPE\x10\x02*k\n\x11\x43ompdatExportType\x12\x16\n\x12TRANSMISSIBILITIES\x10\x00\x12*\n&WPIMULT_AND_DEFAULT_CONNECTION_FACTORS\x10\x01\x12\x12\n\x0eNO_COMPLETIONS\x10\x02*8\n\x16\x43ompdatCombinationMode\x12\x10\n\x0cINDIVIDUALLY\x10\x00\x12\x0c\n\x08\x43OMBINED\x10\x01*v\n\x10\x45xportFolderType\x12\x0f\n\x0b\x43OMPLETIONS\x10\x00\x12\r\n\tSNAPSHOTS\x10\x01\x12\x0e\n\nPROPERTIES\x10\x02\x12\x0e\n\nSTATISTICS\x10\x03\x12\r\n\tWELLPATHS\x10\x04\x12\t\n\x05\x43\x45LLS\x10\x05\x12\x08\n\x04LGRS\x10\x06*K\n\x12MultipleFracAction\x12\x08\n\x04NONE\x10\x00\x12\x14\n\x10\x41PPEND_FRACTURES\x10\x01\x12\x15\n\x11REPLACE_FRACTURES\x10\x02*J\n\x0cLgrSplitType\x12\x10\n\x0cLGR_PER_CELL\x10\x00\x12\x16\n\x12LGR_PER_COMPLETION\x10\x01\x12\x10\n\x0cLGR_PER_WELL\x10\x02*\"\n\x0c\x45xportFormat\x12\x07\n\x03LAS\x10\x00\x12\t\n\x05\x41SCII\x10\x01\x32@\n\x08\x43ommands\x12\x34\n\x07\x45xecute\x12\x13.rips.CommandParams\x1a\x12.rips.CommandReply\"\x00\x62\x06proto3'
  ,
  dependencies=[Case__pb2.DESCRIPTOR,Definitions__pb2.DESCRIPTOR,PdmObject__pb2.DESCRIPTOR,])

_PLOTOUTPUTFORMAT = _descriptor.EnumDescriptor(
  name='PlotOutputFormat',
  full_name='rips.PlotOutputFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PNG', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PDF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7055,
  serialized_end=7091,
)
_sym_db.RegisterEnumDescriptor(_PLOTOUTPUTFORMAT)

PlotOutputFormat = enum_type_wrapper.EnumTypeWrapper(_PLOTOUTPUTFORMAT)
_SNAPSHOTTYPE = _descriptor.EnumDescriptor(
  name='SnapshotType',
  full_name='rips.SnapshotType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VIEWS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLOTS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7093,
  serialized_end=7138,
)
_sym_db.RegisterEnumDescriptor(_SNAPSHOTTYPE)

SnapshotType = enum_type_wrapper.EnumTypeWrapper(_SNAPSHOTTYPE)
_COMPDATEXPORTSPLIT = _descriptor.EnumDescriptor(
  name='CompdatExportSplit',
  full_name='rips.CompdatExportSplit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNIFIED_FILE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPLIT_ON_WELL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPLIT_ON_WELL_AND_COMPLETION_TYPE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7140,
  serialized_end=7236,
)
_sym_db.RegisterEnumDescriptor(_COMPDATEXPORTSPLIT)

CompdatExportSplit = enum_type_wrapper.EnumTypeWrapper(_COMPDATEXPORTSPLIT)
_COMPDATEXPORTTYPE = _descriptor.EnumDescriptor(
  name='CompdatExportType',
  full_name='rips.CompdatExportType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRANSMISSIBILITIES', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WPIMULT_AND_DEFAULT_CONNECTION_FACTORS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_COMPLETIONS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7238,
  serialized_end=7345,
)
_sym_db.RegisterEnumDescriptor(_COMPDATEXPORTTYPE)

CompdatExportType = enum_type_wrapper.EnumTypeWrapper(_COMPDATEXPORTTYPE)
_COMPDATCOMBINATIONMODE = _descriptor.EnumDescriptor(
  name='CompdatCombinationMode',
  full_name='rips.CompdatCombinationMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INDIVIDUALLY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMBINED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7347,
  serialized_end=7403,
)
_sym_db.RegisterEnumDescriptor(_COMPDATCOMBINATIONMODE)

CompdatCombinationMode = enum_type_wrapper.EnumTypeWrapper(_COMPDATCOMBINATIONMODE)
_EXPORTFOLDERTYPE = _descriptor.EnumDescriptor(
  name='ExportFolderType',
  full_name='rips.ExportFolderType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPLETIONS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPSHOTS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPERTIES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATISTICS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WELLPATHS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CELLS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LGRS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7405,
  serialized_end=7523,
)
_sym_db.RegisterEnumDescriptor(_EXPORTFOLDERTYPE)

ExportFolderType = enum_type_wrapper.EnumTypeWrapper(_EXPORTFOLDERTYPE)
_MULTIPLEFRACACTION = _descriptor.EnumDescriptor(
  name='MultipleFracAction',
  full_name='rips.MultipleFracAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPEND_FRACTURES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLACE_FRACTURES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7525,
  serialized_end=7600,
)
_sym_db.RegisterEnumDescriptor(_MULTIPLEFRACACTION)

MultipleFracAction = enum_type_wrapper.EnumTypeWrapper(_MULTIPLEFRACACTION)
_LGRSPLITTYPE = _descriptor.EnumDescriptor(
  name='LgrSplitType',
  full_name='rips.LgrSplitType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LGR_PER_CELL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LGR_PER_COMPLETION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LGR_PER_WELL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7602,
  serialized_end=7676,
)
_sym_db.RegisterEnumDescriptor(_LGRSPLITTYPE)

LgrSplitType = enum_type_wrapper.EnumTypeWrapper(_LGRSPLITTYPE)
_EXPORTFORMAT = _descriptor.EnumDescriptor(
  name='ExportFormat',
  full_name='rips.ExportFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LAS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASCII', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7678,
  serialized_end=7712,
)
_sym_db.RegisterEnumDescriptor(_EXPORTFORMAT)

ExportFormat = enum_type_wrapper.EnumTypeWrapper(_EXPORTFORMAT)
PNG = 0
PDF = 1
VIEWS = 0
PLOTS = 1
ALL = 2
UNIFIED_FILE = 0
SPLIT_ON_WELL = 1
SPLIT_ON_WELL_AND_COMPLETION_TYPE = 2
TRANSMISSIBILITIES = 0
WPIMULT_AND_DEFAULT_CONNECTION_FACTORS = 1
NO_COMPLETIONS = 2
INDIVIDUALLY = 0
COMBINED = 1
COMPLETIONS = 0
SNAPSHOTS = 1
PROPERTIES = 2
STATISTICS = 3
WELLPATHS = 4
CELLS = 5
LGRS = 6
NONE = 0
APPEND_FRACTURES = 1
REPLACE_FRACTURES = 2
LGR_PER_CELL = 0
LGR_PER_COMPLETION = 1
LGR_PER_WELL = 2
LAS = 0
ASCII = 1



_FILEPATHREQUEST = _descriptor.Descriptor(
  name='FilePathRequest',
  full_name='rips.FilePathRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rips.FilePathRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gridOnly', full_name='rips.FilePathRequest.gridOnly', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=121,
)


_REPLACECASEREQUEST = _descriptor.Descriptor(
  name='ReplaceCaseRequest',
  full_name='rips.ReplaceCaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='newGridFile', full_name='rips.ReplaceCaseRequest.newGridFile', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.ReplaceCaseRequest.caseId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=180,
)


_REPLACECASEREQUESTS = _descriptor.Descriptor(
  name='ReplaceCaseRequests',
  full_name='rips.ReplaceCaseRequests',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='casePairs', full_name='rips.ReplaceCaseRequests.casePairs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=248,
)


_REPLACESOURCECASESREQUEST = _descriptor.Descriptor(
  name='ReplaceSourceCasesRequest',
  full_name='rips.ReplaceSourceCasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gridListFile', full_name='rips.ReplaceSourceCasesRequest.gridListFile', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caseGroupId', full_name='rips.ReplaceSourceCasesRequest.caseGroupId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=320,
)


_EXPORTMULTICASEREQUEST = _descriptor.Descriptor(
  name='ExportMultiCaseRequest',
  full_name='rips.ExportMultiCaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gridListFile', full_name='rips.ExportMultiCaseRequest.gridListFile', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=368,
)


_EXPORTSNAPSHOTSREQUEST = _descriptor.Descriptor(
  name='ExportSnapshotsRequest',
  full_name='rips.ExportSnapshotsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rips.ExportSnapshotsRequest.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='rips.ExportSnapshotsRequest.prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.ExportSnapshotsRequest.caseId', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewId', full_name='rips.ExportSnapshotsRequest.viewId', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportFolder', full_name='rips.ExportSnapshotsRequest.exportFolder', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plotOutputFormat', full_name='rips.ExportSnapshotsRequest.plotOutputFormat', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=549,
)


_EXPORTPROPERTYREQUEST = _descriptor.Descriptor(
  name='ExportPropertyRequest',
  full_name='rips.ExportPropertyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.ExportPropertyRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='rips.ExportPropertyRequest.timeStep', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property', full_name='rips.ExportPropertyRequest.property', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eclipseKeyword', full_name='rips.ExportPropertyRequest.eclipseKeyword', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undefinedValue', full_name='rips.ExportPropertyRequest.undefinedValue', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportFile', full_name='rips.ExportPropertyRequest.exportFile', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=695,
)


_EXPORTPROPERTYINVIEWSREQUEST = _descriptor.Descriptor(
  name='ExportPropertyInViewsRequest',
  full_name='rips.ExportPropertyInViewsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.ExportPropertyInViewsRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewIds', full_name='rips.ExportPropertyInViewsRequest.viewIds', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undefinedValue', full_name='rips.ExportPropertyInViewsRequest.undefinedValue', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=784,
)


_EXPORTWELLPATHCOMPREQUEST = _descriptor.Descriptor(
  name='ExportWellPathCompRequest',
  full_name='rips.ExportWellPathCompRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.ExportWellPathCompRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='rips.ExportWellPathCompRequest.timeStep', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wellPathNames', full_name='rips.ExportWellPathCompRequest.wellPathNames', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fileSplit', full_name='rips.ExportWellPathCompRequest.fileSplit', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compdatExport', full_name='rips.ExportWellPathCompRequest.compdatExport', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includePerforations', full_name='rips.ExportWellPathCompRequest.includePerforations', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeFishbones', full_name='rips.ExportWellPathCompRequest.includeFishbones', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excludeMainBoreForFishbones', full_name='rips.ExportWellPathCompRequest.excludeMainBoreForFishbones', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='combinationMode', full_name='rips.ExportWellPathCompRequest.combinationMode', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customFileName', full_name='rips.ExportWellPathCompRequest.customFileName', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportComments', full_name='rips.ExportWellPathCompRequest.exportComments', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportWelspec', full_name='rips.ExportWellPathCompRequest.exportWelspec', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=1182,
)


_EXPORTSIMWELLPATHFRACREQUEST = _descriptor.Descriptor(
  name='ExportSimWellPathFracRequest',
  full_name='rips.ExportSimWellPathFracRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.ExportSimWellPathFracRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewId', full_name='rips.ExportSimWellPathFracRequest.viewId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='rips.ExportSimWellPathFracRequest.timeStep', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulationWellNames', full_name='rips.ExportSimWellPathFracRequest.simulationWellNames', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fileSplit', full_name='rips.ExportSimWellPathFracRequest.fileSplit', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compdatExport', full_name='rips.ExportSimWellPathFracRequest.compdatExport', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1387,
)


_EXPORTMSWREQUEST = _descriptor.Descriptor(
  name='ExportMswRequest',
  full_name='rips.ExportMswRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.ExportMswRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wellPath', full_name='rips.ExportMswRequest.wellPath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1389,
  serialized_end=1441,
)


_EXPORTWELLPATHREQUEST = _descriptor.Descriptor(
  name='ExportWellPathRequest',
  full_name='rips.ExportWellPathRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wellPathNames', full_name='rips.ExportWellPathRequest.wellPathNames', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mdStepSize', full_name='rips.ExportWellPathRequest.mdStepSize', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1509,
)


_EXPORTVISIBLECELLSREQUEST = _descriptor.Descriptor(
  name='ExportVisibleCellsRequest',
  full_name='rips.ExportVisibleCellsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.ExportVisibleCellsRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewId', full_name='rips.ExportVisibleCellsRequest.viewId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportKeyword', full_name='rips.ExportVisibleCellsRequest.exportKeyword', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibleActiveCellsValue', full_name='rips.ExportVisibleCellsRequest.visibleActiveCellsValue', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hiddenActiveCellsValue', full_name='rips.ExportVisibleCellsRequest.hiddenActiveCellsValue', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inactiveCellsValue', full_name='rips.ExportVisibleCellsRequest.inactiveCellsValue', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1512,
  serialized_end=1687,
)


_SETEXPORTFOLDERREQUEST = _descriptor.Descriptor(
  name='SetExportFolderRequest',
  full_name='rips.SetExportFolderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rips.SetExportFolderRequest.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='rips.SetExportFolderRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createFolder', full_name='rips.SetExportFolderRequest.createFolder', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1689,
  serialized_end=1787,
)


_RUNOCTAVESCRIPTREQUEST = _descriptor.Descriptor(
  name='RunOctaveScriptRequest',
  full_name='rips.RunOctaveScriptRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rips.RunOctaveScriptRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caseIds', full_name='rips.RunOctaveScriptRequest.caseIds', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1789,
  serialized_end=1844,
)


_SETWINDOWSIZEPARAMS = _descriptor.Descriptor(
  name='SetWindowSizeParams',
  full_name='rips.SetWindowSizeParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='rips.SetWindowSizeParams.height', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='rips.SetWindowSizeParams.width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1846,
  serialized_end=1898,
)


_COMPUTECASEGROUPSTATREQUEST = _descriptor.Descriptor(
  name='ComputeCaseGroupStatRequest',
  full_name='rips.ComputeCaseGroupStatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseIds', full_name='rips.ComputeCaseGroupStatRequest.caseIds', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caseGroupId', full_name='rips.ComputeCaseGroupStatRequest.caseGroupId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1900,
  serialized_end=1967,
)


_SETTIMESTEPPARAMS = _descriptor.Descriptor(
  name='SetTimeStepParams',
  full_name='rips.SetTimeStepParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.SetTimeStepParams.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewId', full_name='rips.SetTimeStepParams.viewId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='rips.SetTimeStepParams.timeStep', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1969,
  serialized_end=2038,
)


_SCALEFRACTURETEMPLATEREQUEST = _descriptor.Descriptor(
  name='ScaleFractureTemplateRequest',
  full_name='rips.ScaleFractureTemplateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rips.ScaleFractureTemplateRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='halfLength', full_name='rips.ScaleFractureTemplateRequest.halfLength', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='rips.ScaleFractureTemplateRequest.height', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2040,
  serialized_end=2118,
)


_SETFRACCONTAINMENTREQUEST = _descriptor.Descriptor(
  name='SetFracContainmentRequest',
  full_name='rips.SetFracContainmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rips.SetFracContainmentRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topLayer', full_name='rips.SetFracContainmentRequest.topLayer', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseLayer', full_name='rips.SetFracContainmentRequest.baseLayer', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2120,
  serialized_end=2196,
)


_CREATEMULTIPLEFRACREQUEST = _descriptor.Descriptor(
  name='CreateMultipleFracRequest',
  full_name='rips.CreateMultipleFracRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.CreateMultipleFracRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='templateId', full_name='rips.CreateMultipleFracRequest.templateId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wellPathNames', full_name='rips.CreateMultipleFracRequest.wellPathNames', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minDistFromWellTd', full_name='rips.CreateMultipleFracRequest.minDistFromWellTd', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxFracturesPerWell', full_name='rips.CreateMultipleFracRequest.maxFracturesPerWell', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topLayer', full_name='rips.CreateMultipleFracRequest.topLayer', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseLayer', full_name='rips.CreateMultipleFracRequest.baseLayer', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spacing', full_name='rips.CreateMultipleFracRequest.spacing', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='rips.CreateMultipleFracRequest.action', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2199,
  serialized_end=2437,
)


_CREATELGRFORCOMPREQUEST = _descriptor.Descriptor(
  name='CreateLgrForCompRequest',
  full_name='rips.CreateLgrForCompRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.CreateLgrForCompRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='rips.CreateLgrForCompRequest.timeStep', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wellPathNames', full_name='rips.CreateLgrForCompRequest.wellPathNames', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refinementI', full_name='rips.CreateLgrForCompRequest.refinementI', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refinementJ', full_name='rips.CreateLgrForCompRequest.refinementJ', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refinementK', full_name='rips.CreateLgrForCompRequest.refinementK', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='splitType', full_name='rips.CreateLgrForCompRequest.splitType', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2440,
  serialized_end=2624,
)


_CREATESATPRESSPLOTREQUEST = _descriptor.Descriptor(
  name='CreateSatPressPlotRequest',
  full_name='rips.CreateSatPressPlotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseIds', full_name='rips.CreateSatPressPlotRequest.caseIds', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2626,
  serialized_end=2670,
)


_CREATEGRIDCASEGROUPREQUEST = _descriptor.Descriptor(
  name='CreateGridCaseGroupRequest',
  full_name='rips.CreateGridCaseGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='casePaths', full_name='rips.CreateGridCaseGroupRequest.casePaths', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2672,
  serialized_end=2719,
)


_CREATESTATISTICSCASEREQUEST = _descriptor.Descriptor(
  name='CreateStatisticsCaseRequest',
  full_name='rips.CreateStatisticsCaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseGroupId', full_name='rips.CreateStatisticsCaseRequest.caseGroupId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2721,
  serialized_end=2771,
)


_EXPORTFLOWINFOREQUEST = _descriptor.Descriptor(
  name='ExportFlowInfoRequest',
  full_name='rips.ExportFlowInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.ExportFlowInfoRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeSteps', full_name='rips.ExportFlowInfoRequest.timeSteps', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='injectors', full_name='rips.ExportFlowInfoRequest.injectors', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producers', full_name='rips.ExportFlowInfoRequest.producers', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fileName', full_name='rips.ExportFlowInfoRequest.fileName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimumCommunication', full_name='rips.ExportFlowInfoRequest.minimumCommunication', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aquiferCellThreshold', full_name='rips.ExportFlowInfoRequest.aquiferCellThreshold', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2774,
  serialized_end=2948,
)


_CREATEVIEWREQUEST = _descriptor.Descriptor(
  name='CreateViewRequest',
  full_name='rips.CreateViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.CreateViewRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2950,
  serialized_end=2985,
)


_CLONEVIEWREQUEST = _descriptor.Descriptor(
  name='CloneViewRequest',
  full_name='rips.CloneViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='viewId', full_name='rips.CloneViewRequest.viewId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2987,
  serialized_end=3021,
)


_CREATEWBSPLOTREQUEST = _descriptor.Descriptor(
  name='CreateWbsPlotRequest',
  full_name='rips.CreateWbsPlotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.CreateWbsPlotRequest.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wellPath', full_name='rips.CreateWbsPlotRequest.wellPath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='rips.CreateWbsPlotRequest.timeStep', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wbsParameters', full_name='rips.CreateWbsPlotRequest.wbsParameters', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3023,
  serialized_end=3137,
)


_IMPORTWELLPATHSREQUEST = _descriptor.Descriptor(
  name='ImportWellPathsRequest',
  full_name='rips.ImportWellPathsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wellPathFolder', full_name='rips.ImportWellPathsRequest.wellPathFolder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wellPathFiles', full_name='rips.ImportWellPathsRequest.wellPathFiles', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3139,
  serialized_end=3210,
)


_IMPORTWELLLOGFILESREQUEST = _descriptor.Descriptor(
  name='ImportWellLogFilesRequest',
  full_name='rips.ImportWellLogFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wellLogFolder', full_name='rips.ImportWellLogFilesRequest.wellLogFolder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wellLogFiles', full_name='rips.ImportWellLogFilesRequest.wellLogFiles', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3212,
  serialized_end=3284,
)


_IMPORTFORMATIONNAMESREQUEST = _descriptor.Descriptor(
  name='ImportFormationNamesRequest',
  full_name='rips.ImportFormationNamesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='formationFiles', full_name='rips.ImportFormationNamesRequest.formationFiles', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='applyToCaseId', full_name='rips.ImportFormationNamesRequest.applyToCaseId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3286,
  serialized_end=3362,
)


_EXPORTWELLLOGPLOTDATAREQUEST = _descriptor.Descriptor(
  name='ExportWellLogPlotDataRequest',
  full_name='rips.ExportWellLogPlotDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exportFormat', full_name='rips.ExportWellLogPlotDataRequest.exportFormat', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewId', full_name='rips.ExportWellLogPlotDataRequest.viewId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportFolder', full_name='rips.ExportWellLogPlotDataRequest.exportFolder', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filePrefix', full_name='rips.ExportWellLogPlotDataRequest.filePrefix', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportTvdRkb', full_name='rips.ExportWellLogPlotDataRequest.exportTvdRkb', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capitalizeFileNames', full_name='rips.ExportWellLogPlotDataRequest.capitalizeFileNames', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resampleInterval', full_name='rips.ExportWellLogPlotDataRequest.resampleInterval', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='convertCurveUnits', full_name='rips.ExportWellLogPlotDataRequest.convertCurveUnits', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3365,
  serialized_end=3599,
)


_EXPORTCONTOURMAPTOTEXTREQUEST = _descriptor.Descriptor(
  name='ExportContourMapToTextRequest',
  full_name='rips.ExportContourMapToTextRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exportFileName', full_name='rips.ExportContourMapToTextRequest.exportFileName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportLocalCoordinates', full_name='rips.ExportContourMapToTextRequest.exportLocalCoordinates', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undefinedValueLabel', full_name='rips.ExportContourMapToTextRequest.undefinedValueLabel', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excludeUndefinedValues', full_name='rips.ExportContourMapToTextRequest.excludeUndefinedValues', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewId', full_name='rips.ExportContourMapToTextRequest.viewId', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3602,
  serialized_end=3766,
)


_SAVEPROJECTREQUEST = _descriptor.Descriptor(
  name='SaveProjectRequest',
  full_name='rips.SaveProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filePath', full_name='rips.SaveProjectRequest.filePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3768,
  serialized_end=3806,
)


_COMMANDPARAMS = _descriptor.Descriptor(
  name='CommandParams',
  full_name='rips.CommandParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openProject', full_name='rips.CommandParams.openProject', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closeProject', full_name='rips.CommandParams.closeProject', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setStartDir', full_name='rips.CommandParams.setStartDir', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loadCase', full_name='rips.CommandParams.loadCase', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replaceCase', full_name='rips.CommandParams.replaceCase', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replaceSourceCases', full_name='rips.CommandParams.replaceSourceCases', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportMultiCaseSnapshots', full_name='rips.CommandParams.exportMultiCaseSnapshots', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportSnapshots', full_name='rips.CommandParams.exportSnapshots', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportProperty', full_name='rips.CommandParams.exportProperty', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportPropertyInViews', full_name='rips.CommandParams.exportPropertyInViews', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportWellPathCompletions', full_name='rips.CommandParams.exportWellPathCompletions', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportSimWellFractureCompletions', full_name='rips.CommandParams.exportSimWellFractureCompletions', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportMsw', full_name='rips.CommandParams.exportMsw', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportWellPaths', full_name='rips.CommandParams.exportWellPaths', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportVisibleCells', full_name='rips.CommandParams.exportVisibleCells', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setExportFolder', full_name='rips.CommandParams.setExportFolder', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runOctaveScript', full_name='rips.CommandParams.runOctaveScript', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setMainWindowSize', full_name='rips.CommandParams.setMainWindowSize', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computeCaseGroupStatistics', full_name='rips.CommandParams.computeCaseGroupStatistics', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setTimeStep', full_name='rips.CommandParams.setTimeStep', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scaleFractureTemplate', full_name='rips.CommandParams.scaleFractureTemplate', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setFractureContainment', full_name='rips.CommandParams.setFractureContainment', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createMultipleFractures', full_name='rips.CommandParams.createMultipleFractures', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createLgrForCompletions', full_name='rips.CommandParams.createLgrForCompletions', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createSaturationPressurePlots', full_name='rips.CommandParams.createSaturationPressurePlots', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replaceMultipleCases', full_name='rips.CommandParams.replaceMultipleCases', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createGridCaseGroup', full_name='rips.CommandParams.createGridCaseGroup', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createStatisticsCase', full_name='rips.CommandParams.createStatisticsCase', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportFlowCharacteristics', full_name='rips.CommandParams.exportFlowCharacteristics', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createView', full_name='rips.CommandParams.createView', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloneView', full_name='rips.CommandParams.cloneView', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createWellBoreStabilityPlot', full_name='rips.CommandParams.createWellBoreStabilityPlot', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importWellPaths', full_name='rips.CommandParams.importWellPaths', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importWellLogFiles', full_name='rips.CommandParams.importWellLogFiles', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importFormationNames', full_name='rips.CommandParams.importFormationNames', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportWellLogPlotData', full_name='rips.CommandParams.exportWellLogPlotData', index=35,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setPlotWindowSize', full_name='rips.CommandParams.setPlotWindowSize', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportContourMapToText', full_name='rips.CommandParams.exportContourMapToText', index=37,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saveProject', full_name='rips.CommandParams.saveProject', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='params', full_name='rips.CommandParams.params',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3809,
  serialized_end=6162,
)


_GRIDCASEGROUPRESULT = _descriptor.Descriptor(
  name='GridCaseGroupResult',
  full_name='rips.GridCaseGroupResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupId', full_name='rips.GridCaseGroupResult.groupId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupName', full_name='rips.GridCaseGroupResult.groupName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6164,
  serialized_end=6221,
)


_CREATESTATISTICSCASERESULT = _descriptor.Descriptor(
  name='CreateStatisticsCaseResult',
  full_name='rips.CreateStatisticsCaseResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseId', full_name='rips.CreateStatisticsCaseResult.caseId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6223,
  serialized_end=6267,
)


_CREATEVIEWRESULT = _descriptor.Descriptor(
  name='CreateViewResult',
  full_name='rips.CreateViewResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='viewId', full_name='rips.CreateViewResult.viewId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6269,
  serialized_end=6303,
)


_CREATEWBSPLOTRESULT = _descriptor.Descriptor(
  name='CreateWbsPlotResult',
  full_name='rips.CreateWbsPlotResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='viewId', full_name='rips.CreateWbsPlotResult.viewId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6305,
  serialized_end=6342,
)


_IMPORTWELLPATHSRESULT = _descriptor.Descriptor(
  name='ImportWellPathsResult',
  full_name='rips.ImportWellPathsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wellPathNames', full_name='rips.ImportWellPathsResult.wellPathNames', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6344,
  serialized_end=6390,
)


_IMPORTWELLLOGFILESRESULT = _descriptor.Descriptor(
  name='ImportWellLogFilesResult',
  full_name='rips.ImportWellLogFilesResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wellPathNames', full_name='rips.ImportWellLogFilesResult.wellPathNames', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6392,
  serialized_end=6441,
)


_EXPORTWELLLOGPLOTDATARESULT = _descriptor.Descriptor(
  name='ExportWellLogPlotDataResult',
  full_name='rips.ExportWellLogPlotDataResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exportedFiles', full_name='rips.ExportWellLogPlotDataResult.exportedFiles', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6443,
  serialized_end=6495,
)


_COMMANDREPLY = _descriptor.Descriptor(
  name='CommandReply',
  full_name='rips.CommandReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='emptyResult', full_name='rips.CommandReply.emptyResult', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loadCaseResult', full_name='rips.CommandReply.loadCaseResult', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createGridCaseGroupResult', full_name='rips.CommandReply.createGridCaseGroupResult', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createStatisticsCaseResult', full_name='rips.CommandReply.createStatisticsCaseResult', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createViewResult', full_name='rips.CommandReply.createViewResult', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createWbsPlotResult', full_name='rips.CommandReply.createWbsPlotResult', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importWellPathsResult', full_name='rips.CommandReply.importWellPathsResult', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importWellLogFilesResult', full_name='rips.CommandReply.importWellLogFilesResult', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exportWellLogPlotDataResult', full_name='rips.CommandReply.exportWellLogPlotDataResult', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='rips.CommandReply.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6498,
  serialized_end=7053,
)

_REPLACECASEREQUESTS.fields_by_name['casePairs'].message_type = _REPLACECASEREQUEST
_EXPORTSNAPSHOTSREQUEST.fields_by_name['type'].enum_type = _SNAPSHOTTYPE
_EXPORTSNAPSHOTSREQUEST.fields_by_name['plotOutputFormat'].enum_type = _PLOTOUTPUTFORMAT
_EXPORTWELLPATHCOMPREQUEST.fields_by_name['fileSplit'].enum_type = _COMPDATEXPORTSPLIT
_EXPORTWELLPATHCOMPREQUEST.fields_by_name['compdatExport'].enum_type = _COMPDATEXPORTTYPE
_EXPORTWELLPATHCOMPREQUEST.fields_by_name['combinationMode'].enum_type = _COMPDATCOMBINATIONMODE
_EXPORTSIMWELLPATHFRACREQUEST.fields_by_name['fileSplit'].enum_type = _COMPDATEXPORTSPLIT
_EXPORTSIMWELLPATHFRACREQUEST.fields_by_name['compdatExport'].enum_type = _COMPDATEXPORTTYPE
_SETEXPORTFOLDERREQUEST.fields_by_name['type'].enum_type = _EXPORTFOLDERTYPE
_CREATEMULTIPLEFRACREQUEST.fields_by_name['action'].enum_type = _MULTIPLEFRACACTION
_CREATELGRFORCOMPREQUEST.fields_by_name['splitType'].enum_type = _LGRSPLITTYPE
_CREATEWBSPLOTREQUEST.fields_by_name['wbsParameters'].message_type = PdmObject__pb2._PDMOBJECT
_EXPORTWELLLOGPLOTDATAREQUEST.fields_by_name['exportFormat'].enum_type = _EXPORTFORMAT
_COMMANDPARAMS.fields_by_name['openProject'].message_type = _FILEPATHREQUEST
_COMMANDPARAMS.fields_by_name['closeProject'].message_type = Definitions__pb2._EMPTY
_COMMANDPARAMS.fields_by_name['setStartDir'].message_type = _FILEPATHREQUEST
_COMMANDPARAMS.fields_by_name['loadCase'].message_type = _FILEPATHREQUEST
_COMMANDPARAMS.fields_by_name['replaceCase'].message_type = _REPLACECASEREQUEST
_COMMANDPARAMS.fields_by_name['replaceSourceCases'].message_type = _REPLACESOURCECASESREQUEST
_COMMANDPARAMS.fields_by_name['exportMultiCaseSnapshots'].message_type = _EXPORTMULTICASEREQUEST
_COMMANDPARAMS.fields_by_name['exportSnapshots'].message_type = _EXPORTSNAPSHOTSREQUEST
_COMMANDPARAMS.fields_by_name['exportProperty'].message_type = _EXPORTPROPERTYREQUEST
_COMMANDPARAMS.fields_by_name['exportPropertyInViews'].message_type = _EXPORTPROPERTYINVIEWSREQUEST
_COMMANDPARAMS.fields_by_name['exportWellPathCompletions'].message_type = _EXPORTWELLPATHCOMPREQUEST
_COMMANDPARAMS.fields_by_name['exportSimWellFractureCompletions'].message_type = _EXPORTSIMWELLPATHFRACREQUEST
_COMMANDPARAMS.fields_by_name['exportMsw'].message_type = _EXPORTMSWREQUEST
_COMMANDPARAMS.fields_by_name['exportWellPaths'].message_type = _EXPORTWELLPATHREQUEST
_COMMANDPARAMS.fields_by_name['exportVisibleCells'].message_type = _EXPORTVISIBLECELLSREQUEST
_COMMANDPARAMS.fields_by_name['setExportFolder'].message_type = _SETEXPORTFOLDERREQUEST
_COMMANDPARAMS.fields_by_name['runOctaveScript'].message_type = _RUNOCTAVESCRIPTREQUEST
_COMMANDPARAMS.fields_by_name['setMainWindowSize'].message_type = _SETWINDOWSIZEPARAMS
_COMMANDPARAMS.fields_by_name['computeCaseGroupStatistics'].message_type = _COMPUTECASEGROUPSTATREQUEST
_COMMANDPARAMS.fields_by_name['setTimeStep'].message_type = _SETTIMESTEPPARAMS
_COMMANDPARAMS.fields_by_name['scaleFractureTemplate'].message_type = _SCALEFRACTURETEMPLATEREQUEST
_COMMANDPARAMS.fields_by_name['setFractureContainment'].message_type = _SETFRACCONTAINMENTREQUEST
_COMMANDPARAMS.fields_by_name['createMultipleFractures'].message_type = _CREATEMULTIPLEFRACREQUEST
_COMMANDPARAMS.fields_by_name['createLgrForCompletions'].message_type = _CREATELGRFORCOMPREQUEST
_COMMANDPARAMS.fields_by_name['createSaturationPressurePlots'].message_type = _CREATESATPRESSPLOTREQUEST
_COMMANDPARAMS.fields_by_name['replaceMultipleCases'].message_type = _REPLACECASEREQUESTS
_COMMANDPARAMS.fields_by_name['createGridCaseGroup'].message_type = _CREATEGRIDCASEGROUPREQUEST
_COMMANDPARAMS.fields_by_name['createStatisticsCase'].message_type = _CREATESTATISTICSCASEREQUEST
_COMMANDPARAMS.fields_by_name['exportFlowCharacteristics'].message_type = _EXPORTFLOWINFOREQUEST
_COMMANDPARAMS.fields_by_name['createView'].message_type = _CREATEVIEWREQUEST
_COMMANDPARAMS.fields_by_name['cloneView'].message_type = _CLONEVIEWREQUEST
_COMMANDPARAMS.fields_by_name['createWellBoreStabilityPlot'].message_type = _CREATEWBSPLOTREQUEST
_COMMANDPARAMS.fields_by_name['importWellPaths'].message_type = _IMPORTWELLPATHSREQUEST
_COMMANDPARAMS.fields_by_name['importWellLogFiles'].message_type = _IMPORTWELLLOGFILESREQUEST
_COMMANDPARAMS.fields_by_name['importFormationNames'].message_type = _IMPORTFORMATIONNAMESREQUEST
_COMMANDPARAMS.fields_by_name['exportWellLogPlotData'].message_type = _EXPORTWELLLOGPLOTDATAREQUEST
_COMMANDPARAMS.fields_by_name['setPlotWindowSize'].message_type = _SETWINDOWSIZEPARAMS
_COMMANDPARAMS.fields_by_name['exportContourMapToText'].message_type = _EXPORTCONTOURMAPTOTEXTREQUEST
_COMMANDPARAMS.fields_by_name['saveProject'].message_type = _SAVEPROJECTREQUEST
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['openProject'])
_COMMANDPARAMS.fields_by_name['openProject'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['closeProject'])
_COMMANDPARAMS.fields_by_name['closeProject'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['setStartDir'])
_COMMANDPARAMS.fields_by_name['setStartDir'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['loadCase'])
_COMMANDPARAMS.fields_by_name['loadCase'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['replaceCase'])
_COMMANDPARAMS.fields_by_name['replaceCase'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['replaceSourceCases'])
_COMMANDPARAMS.fields_by_name['replaceSourceCases'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportMultiCaseSnapshots'])
_COMMANDPARAMS.fields_by_name['exportMultiCaseSnapshots'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportSnapshots'])
_COMMANDPARAMS.fields_by_name['exportSnapshots'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportProperty'])
_COMMANDPARAMS.fields_by_name['exportProperty'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportPropertyInViews'])
_COMMANDPARAMS.fields_by_name['exportPropertyInViews'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportWellPathCompletions'])
_COMMANDPARAMS.fields_by_name['exportWellPathCompletions'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportSimWellFractureCompletions'])
_COMMANDPARAMS.fields_by_name['exportSimWellFractureCompletions'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportMsw'])
_COMMANDPARAMS.fields_by_name['exportMsw'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportWellPaths'])
_COMMANDPARAMS.fields_by_name['exportWellPaths'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportVisibleCells'])
_COMMANDPARAMS.fields_by_name['exportVisibleCells'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['setExportFolder'])
_COMMANDPARAMS.fields_by_name['setExportFolder'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['runOctaveScript'])
_COMMANDPARAMS.fields_by_name['runOctaveScript'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['setMainWindowSize'])
_COMMANDPARAMS.fields_by_name['setMainWindowSize'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['computeCaseGroupStatistics'])
_COMMANDPARAMS.fields_by_name['computeCaseGroupStatistics'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['setTimeStep'])
_COMMANDPARAMS.fields_by_name['setTimeStep'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['scaleFractureTemplate'])
_COMMANDPARAMS.fields_by_name['scaleFractureTemplate'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['setFractureContainment'])
_COMMANDPARAMS.fields_by_name['setFractureContainment'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['createMultipleFractures'])
_COMMANDPARAMS.fields_by_name['createMultipleFractures'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['createLgrForCompletions'])
_COMMANDPARAMS.fields_by_name['createLgrForCompletions'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['createSaturationPressurePlots'])
_COMMANDPARAMS.fields_by_name['createSaturationPressurePlots'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['replaceMultipleCases'])
_COMMANDPARAMS.fields_by_name['replaceMultipleCases'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['createGridCaseGroup'])
_COMMANDPARAMS.fields_by_name['createGridCaseGroup'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['createStatisticsCase'])
_COMMANDPARAMS.fields_by_name['createStatisticsCase'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportFlowCharacteristics'])
_COMMANDPARAMS.fields_by_name['exportFlowCharacteristics'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['createView'])
_COMMANDPARAMS.fields_by_name['createView'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['cloneView'])
_COMMANDPARAMS.fields_by_name['cloneView'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['createWellBoreStabilityPlot'])
_COMMANDPARAMS.fields_by_name['createWellBoreStabilityPlot'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['importWellPaths'])
_COMMANDPARAMS.fields_by_name['importWellPaths'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['importWellLogFiles'])
_COMMANDPARAMS.fields_by_name['importWellLogFiles'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['importFormationNames'])
_COMMANDPARAMS.fields_by_name['importFormationNames'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportWellLogPlotData'])
_COMMANDPARAMS.fields_by_name['exportWellLogPlotData'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['setPlotWindowSize'])
_COMMANDPARAMS.fields_by_name['setPlotWindowSize'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['exportContourMapToText'])
_COMMANDPARAMS.fields_by_name['exportContourMapToText'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDPARAMS.oneofs_by_name['params'].fields.append(
  _COMMANDPARAMS.fields_by_name['saveProject'])
_COMMANDPARAMS.fields_by_name['saveProject'].containing_oneof = _COMMANDPARAMS.oneofs_by_name['params']
_COMMANDREPLY.fields_by_name['emptyResult'].message_type = Definitions__pb2._EMPTY
_COMMANDREPLY.fields_by_name['loadCaseResult'].message_type = Case__pb2._CASEREQUEST
_COMMANDREPLY.fields_by_name['createGridCaseGroupResult'].message_type = _GRIDCASEGROUPRESULT
_COMMANDREPLY.fields_by_name['createStatisticsCaseResult'].message_type = _CREATESTATISTICSCASERESULT
_COMMANDREPLY.fields_by_name['createViewResult'].message_type = _CREATEVIEWRESULT
_COMMANDREPLY.fields_by_name['createWbsPlotResult'].message_type = _CREATEWBSPLOTRESULT
_COMMANDREPLY.fields_by_name['importWellPathsResult'].message_type = _IMPORTWELLPATHSRESULT
_COMMANDREPLY.fields_by_name['importWellLogFilesResult'].message_type = _IMPORTWELLLOGFILESRESULT
_COMMANDREPLY.fields_by_name['exportWellLogPlotDataResult'].message_type = _EXPORTWELLLOGPLOTDATARESULT
_COMMANDREPLY.oneofs_by_name['result'].fields.append(
  _COMMANDREPLY.fields_by_name['emptyResult'])
_COMMANDREPLY.fields_by_name['emptyResult'].containing_oneof = _COMMANDREPLY.oneofs_by_name['result']
_COMMANDREPLY.oneofs_by_name['result'].fields.append(
  _COMMANDREPLY.fields_by_name['loadCaseResult'])
_COMMANDREPLY.fields_by_name['loadCaseResult'].containing_oneof = _COMMANDREPLY.oneofs_by_name['result']
_COMMANDREPLY.oneofs_by_name['result'].fields.append(
  _COMMANDREPLY.fields_by_name['createGridCaseGroupResult'])
_COMMANDREPLY.fields_by_name['createGridCaseGroupResult'].containing_oneof = _COMMANDREPLY.oneofs_by_name['result']
_COMMANDREPLY.oneofs_by_name['result'].fields.append(
  _COMMANDREPLY.fields_by_name['createStatisticsCaseResult'])
_COMMANDREPLY.fields_by_name['createStatisticsCaseResult'].containing_oneof = _COMMANDREPLY.oneofs_by_name['result']
_COMMANDREPLY.oneofs_by_name['result'].fields.append(
  _COMMANDREPLY.fields_by_name['createViewResult'])
_COMMANDREPLY.fields_by_name['createViewResult'].containing_oneof = _COMMANDREPLY.oneofs_by_name['result']
_COMMANDREPLY.oneofs_by_name['result'].fields.append(
  _COMMANDREPLY.fields_by_name['createWbsPlotResult'])
_COMMANDREPLY.fields_by_name['createWbsPlotResult'].containing_oneof = _COMMANDREPLY.oneofs_by_name['result']
_COMMANDREPLY.oneofs_by_name['result'].fields.append(
  _COMMANDREPLY.fields_by_name['importWellPathsResult'])
_COMMANDREPLY.fields_by_name['importWellPathsResult'].containing_oneof = _COMMANDREPLY.oneofs_by_name['result']
_COMMANDREPLY.oneofs_by_name['result'].fields.append(
  _COMMANDREPLY.fields_by_name['importWellLogFilesResult'])
_COMMANDREPLY.fields_by_name['importWellLogFilesResult'].containing_oneof = _COMMANDREPLY.oneofs_by_name['result']
_COMMANDREPLY.oneofs_by_name['result'].fields.append(
  _COMMANDREPLY.fields_by_name['exportWellLogPlotDataResult'])
_COMMANDREPLY.fields_by_name['exportWellLogPlotDataResult'].containing_oneof = _COMMANDREPLY.oneofs_by_name['result']
DESCRIPTOR.message_types_by_name['FilePathRequest'] = _FILEPATHREQUEST
DESCRIPTOR.message_types_by_name['ReplaceCaseRequest'] = _REPLACECASEREQUEST
DESCRIPTOR.message_types_by_name['ReplaceCaseRequests'] = _REPLACECASEREQUESTS
DESCRIPTOR.message_types_by_name['ReplaceSourceCasesRequest'] = _REPLACESOURCECASESREQUEST
DESCRIPTOR.message_types_by_name['ExportMultiCaseRequest'] = _EXPORTMULTICASEREQUEST
DESCRIPTOR.message_types_by_name['ExportSnapshotsRequest'] = _EXPORTSNAPSHOTSREQUEST
DESCRIPTOR.message_types_by_name['ExportPropertyRequest'] = _EXPORTPROPERTYREQUEST
DESCRIPTOR.message_types_by_name['ExportPropertyInViewsRequest'] = _EXPORTPROPERTYINVIEWSREQUEST
DESCRIPTOR.message_types_by_name['ExportWellPathCompRequest'] = _EXPORTWELLPATHCOMPREQUEST
DESCRIPTOR.message_types_by_name['ExportSimWellPathFracRequest'] = _EXPORTSIMWELLPATHFRACREQUEST
DESCRIPTOR.message_types_by_name['ExportMswRequest'] = _EXPORTMSWREQUEST
DESCRIPTOR.message_types_by_name['ExportWellPathRequest'] = _EXPORTWELLPATHREQUEST
DESCRIPTOR.message_types_by_name['ExportVisibleCellsRequest'] = _EXPORTVISIBLECELLSREQUEST
DESCRIPTOR.message_types_by_name['SetExportFolderRequest'] = _SETEXPORTFOLDERREQUEST
DESCRIPTOR.message_types_by_name['RunOctaveScriptRequest'] = _RUNOCTAVESCRIPTREQUEST
DESCRIPTOR.message_types_by_name['SetWindowSizeParams'] = _SETWINDOWSIZEPARAMS
DESCRIPTOR.message_types_by_name['ComputeCaseGroupStatRequest'] = _COMPUTECASEGROUPSTATREQUEST
DESCRIPTOR.message_types_by_name['SetTimeStepParams'] = _SETTIMESTEPPARAMS
DESCRIPTOR.message_types_by_name['ScaleFractureTemplateRequest'] = _SCALEFRACTURETEMPLATEREQUEST
DESCRIPTOR.message_types_by_name['SetFracContainmentRequest'] = _SETFRACCONTAINMENTREQUEST
DESCRIPTOR.message_types_by_name['CreateMultipleFracRequest'] = _CREATEMULTIPLEFRACREQUEST
DESCRIPTOR.message_types_by_name['CreateLgrForCompRequest'] = _CREATELGRFORCOMPREQUEST
DESCRIPTOR.message_types_by_name['CreateSatPressPlotRequest'] = _CREATESATPRESSPLOTREQUEST
DESCRIPTOR.message_types_by_name['CreateGridCaseGroupRequest'] = _CREATEGRIDCASEGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateStatisticsCaseRequest'] = _CREATESTATISTICSCASEREQUEST
DESCRIPTOR.message_types_by_name['ExportFlowInfoRequest'] = _EXPORTFLOWINFOREQUEST
DESCRIPTOR.message_types_by_name['CreateViewRequest'] = _CREATEVIEWREQUEST
DESCRIPTOR.message_types_by_name['CloneViewRequest'] = _CLONEVIEWREQUEST
DESCRIPTOR.message_types_by_name['CreateWbsPlotRequest'] = _CREATEWBSPLOTREQUEST
DESCRIPTOR.message_types_by_name['ImportWellPathsRequest'] = _IMPORTWELLPATHSREQUEST
DESCRIPTOR.message_types_by_name['ImportWellLogFilesRequest'] = _IMPORTWELLLOGFILESREQUEST
DESCRIPTOR.message_types_by_name['ImportFormationNamesRequest'] = _IMPORTFORMATIONNAMESREQUEST
DESCRIPTOR.message_types_by_name['ExportWellLogPlotDataRequest'] = _EXPORTWELLLOGPLOTDATAREQUEST
DESCRIPTOR.message_types_by_name['ExportContourMapToTextRequest'] = _EXPORTCONTOURMAPTOTEXTREQUEST
DESCRIPTOR.message_types_by_name['SaveProjectRequest'] = _SAVEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['CommandParams'] = _COMMANDPARAMS
DESCRIPTOR.message_types_by_name['GridCaseGroupResult'] = _GRIDCASEGROUPRESULT
DESCRIPTOR.message_types_by_name['CreateStatisticsCaseResult'] = _CREATESTATISTICSCASERESULT
DESCRIPTOR.message_types_by_name['CreateViewResult'] = _CREATEVIEWRESULT
DESCRIPTOR.message_types_by_name['CreateWbsPlotResult'] = _CREATEWBSPLOTRESULT
DESCRIPTOR.message_types_by_name['ImportWellPathsResult'] = _IMPORTWELLPATHSRESULT
DESCRIPTOR.message_types_by_name['ImportWellLogFilesResult'] = _IMPORTWELLLOGFILESRESULT
DESCRIPTOR.message_types_by_name['ExportWellLogPlotDataResult'] = _EXPORTWELLLOGPLOTDATARESULT
DESCRIPTOR.message_types_by_name['CommandReply'] = _COMMANDREPLY
DESCRIPTOR.enum_types_by_name['PlotOutputFormat'] = _PLOTOUTPUTFORMAT
DESCRIPTOR.enum_types_by_name['SnapshotType'] = _SNAPSHOTTYPE
DESCRIPTOR.enum_types_by_name['CompdatExportSplit'] = _COMPDATEXPORTSPLIT
DESCRIPTOR.enum_types_by_name['CompdatExportType'] = _COMPDATEXPORTTYPE
DESCRIPTOR.enum_types_by_name['CompdatCombinationMode'] = _COMPDATCOMBINATIONMODE
DESCRIPTOR.enum_types_by_name['ExportFolderType'] = _EXPORTFOLDERTYPE
DESCRIPTOR.enum_types_by_name['MultipleFracAction'] = _MULTIPLEFRACACTION
DESCRIPTOR.enum_types_by_name['LgrSplitType'] = _LGRSPLITTYPE
DESCRIPTOR.enum_types_by_name['ExportFormat'] = _EXPORTFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FilePathRequest = _reflection.GeneratedProtocolMessageType('FilePathRequest', (_message.Message,), {
  'DESCRIPTOR' : _FILEPATHREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.FilePathRequest)
  })
_sym_db.RegisterMessage(FilePathRequest)

ReplaceCaseRequest = _reflection.GeneratedProtocolMessageType('ReplaceCaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPLACECASEREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ReplaceCaseRequest)
  })
_sym_db.RegisterMessage(ReplaceCaseRequest)

ReplaceCaseRequests = _reflection.GeneratedProtocolMessageType('ReplaceCaseRequests', (_message.Message,), {
  'DESCRIPTOR' : _REPLACECASEREQUESTS,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ReplaceCaseRequests)
  })
_sym_db.RegisterMessage(ReplaceCaseRequests)

ReplaceSourceCasesRequest = _reflection.GeneratedProtocolMessageType('ReplaceSourceCasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPLACESOURCECASESREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ReplaceSourceCasesRequest)
  })
_sym_db.RegisterMessage(ReplaceSourceCasesRequest)

ExportMultiCaseRequest = _reflection.GeneratedProtocolMessageType('ExportMultiCaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTMULTICASEREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportMultiCaseRequest)
  })
_sym_db.RegisterMessage(ExportMultiCaseRequest)

ExportSnapshotsRequest = _reflection.GeneratedProtocolMessageType('ExportSnapshotsRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTSNAPSHOTSREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportSnapshotsRequest)
  })
_sym_db.RegisterMessage(ExportSnapshotsRequest)

ExportPropertyRequest = _reflection.GeneratedProtocolMessageType('ExportPropertyRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTPROPERTYREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportPropertyRequest)
  })
_sym_db.RegisterMessage(ExportPropertyRequest)

ExportPropertyInViewsRequest = _reflection.GeneratedProtocolMessageType('ExportPropertyInViewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTPROPERTYINVIEWSREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportPropertyInViewsRequest)
  })
_sym_db.RegisterMessage(ExportPropertyInViewsRequest)

ExportWellPathCompRequest = _reflection.GeneratedProtocolMessageType('ExportWellPathCompRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTWELLPATHCOMPREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportWellPathCompRequest)
  })
_sym_db.RegisterMessage(ExportWellPathCompRequest)

ExportSimWellPathFracRequest = _reflection.GeneratedProtocolMessageType('ExportSimWellPathFracRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTSIMWELLPATHFRACREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportSimWellPathFracRequest)
  })
_sym_db.RegisterMessage(ExportSimWellPathFracRequest)

ExportMswRequest = _reflection.GeneratedProtocolMessageType('ExportMswRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTMSWREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportMswRequest)
  })
_sym_db.RegisterMessage(ExportMswRequest)

ExportWellPathRequest = _reflection.GeneratedProtocolMessageType('ExportWellPathRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTWELLPATHREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportWellPathRequest)
  })
_sym_db.RegisterMessage(ExportWellPathRequest)

ExportVisibleCellsRequest = _reflection.GeneratedProtocolMessageType('ExportVisibleCellsRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTVISIBLECELLSREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportVisibleCellsRequest)
  })
_sym_db.RegisterMessage(ExportVisibleCellsRequest)

SetExportFolderRequest = _reflection.GeneratedProtocolMessageType('SetExportFolderRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETEXPORTFOLDERREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.SetExportFolderRequest)
  })
_sym_db.RegisterMessage(SetExportFolderRequest)

RunOctaveScriptRequest = _reflection.GeneratedProtocolMessageType('RunOctaveScriptRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNOCTAVESCRIPTREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.RunOctaveScriptRequest)
  })
_sym_db.RegisterMessage(RunOctaveScriptRequest)

SetWindowSizeParams = _reflection.GeneratedProtocolMessageType('SetWindowSizeParams', (_message.Message,), {
  'DESCRIPTOR' : _SETWINDOWSIZEPARAMS,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.SetWindowSizeParams)
  })
_sym_db.RegisterMessage(SetWindowSizeParams)

ComputeCaseGroupStatRequest = _reflection.GeneratedProtocolMessageType('ComputeCaseGroupStatRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTECASEGROUPSTATREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ComputeCaseGroupStatRequest)
  })
_sym_db.RegisterMessage(ComputeCaseGroupStatRequest)

SetTimeStepParams = _reflection.GeneratedProtocolMessageType('SetTimeStepParams', (_message.Message,), {
  'DESCRIPTOR' : _SETTIMESTEPPARAMS,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.SetTimeStepParams)
  })
_sym_db.RegisterMessage(SetTimeStepParams)

ScaleFractureTemplateRequest = _reflection.GeneratedProtocolMessageType('ScaleFractureTemplateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCALEFRACTURETEMPLATEREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ScaleFractureTemplateRequest)
  })
_sym_db.RegisterMessage(ScaleFractureTemplateRequest)

SetFracContainmentRequest = _reflection.GeneratedProtocolMessageType('SetFracContainmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETFRACCONTAINMENTREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.SetFracContainmentRequest)
  })
_sym_db.RegisterMessage(SetFracContainmentRequest)

CreateMultipleFracRequest = _reflection.GeneratedProtocolMessageType('CreateMultipleFracRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMULTIPLEFRACREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateMultipleFracRequest)
  })
_sym_db.RegisterMessage(CreateMultipleFracRequest)

CreateLgrForCompRequest = _reflection.GeneratedProtocolMessageType('CreateLgrForCompRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELGRFORCOMPREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateLgrForCompRequest)
  })
_sym_db.RegisterMessage(CreateLgrForCompRequest)

CreateSatPressPlotRequest = _reflection.GeneratedProtocolMessageType('CreateSatPressPlotRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESATPRESSPLOTREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateSatPressPlotRequest)
  })
_sym_db.RegisterMessage(CreateSatPressPlotRequest)

CreateGridCaseGroupRequest = _reflection.GeneratedProtocolMessageType('CreateGridCaseGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGRIDCASEGROUPREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateGridCaseGroupRequest)
  })
_sym_db.RegisterMessage(CreateGridCaseGroupRequest)

CreateStatisticsCaseRequest = _reflection.GeneratedProtocolMessageType('CreateStatisticsCaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTATISTICSCASEREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateStatisticsCaseRequest)
  })
_sym_db.RegisterMessage(CreateStatisticsCaseRequest)

ExportFlowInfoRequest = _reflection.GeneratedProtocolMessageType('ExportFlowInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTFLOWINFOREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportFlowInfoRequest)
  })
_sym_db.RegisterMessage(ExportFlowInfoRequest)

CreateViewRequest = _reflection.GeneratedProtocolMessageType('CreateViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIEWREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateViewRequest)
  })
_sym_db.RegisterMessage(CreateViewRequest)

CloneViewRequest = _reflection.GeneratedProtocolMessageType('CloneViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLONEVIEWREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CloneViewRequest)
  })
_sym_db.RegisterMessage(CloneViewRequest)

CreateWbsPlotRequest = _reflection.GeneratedProtocolMessageType('CreateWbsPlotRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWBSPLOTREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateWbsPlotRequest)
  })
_sym_db.RegisterMessage(CreateWbsPlotRequest)

ImportWellPathsRequest = _reflection.GeneratedProtocolMessageType('ImportWellPathsRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTWELLPATHSREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ImportWellPathsRequest)
  })
_sym_db.RegisterMessage(ImportWellPathsRequest)

ImportWellLogFilesRequest = _reflection.GeneratedProtocolMessageType('ImportWellLogFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTWELLLOGFILESREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ImportWellLogFilesRequest)
  })
_sym_db.RegisterMessage(ImportWellLogFilesRequest)

ImportFormationNamesRequest = _reflection.GeneratedProtocolMessageType('ImportFormationNamesRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTFORMATIONNAMESREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ImportFormationNamesRequest)
  })
_sym_db.RegisterMessage(ImportFormationNamesRequest)

ExportWellLogPlotDataRequest = _reflection.GeneratedProtocolMessageType('ExportWellLogPlotDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTWELLLOGPLOTDATAREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportWellLogPlotDataRequest)
  })
_sym_db.RegisterMessage(ExportWellLogPlotDataRequest)

ExportContourMapToTextRequest = _reflection.GeneratedProtocolMessageType('ExportContourMapToTextRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTCONTOURMAPTOTEXTREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportContourMapToTextRequest)
  })
_sym_db.RegisterMessage(ExportContourMapToTextRequest)

SaveProjectRequest = _reflection.GeneratedProtocolMessageType('SaveProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVEPROJECTREQUEST,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.SaveProjectRequest)
  })
_sym_db.RegisterMessage(SaveProjectRequest)

CommandParams = _reflection.GeneratedProtocolMessageType('CommandParams', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDPARAMS,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CommandParams)
  })
_sym_db.RegisterMessage(CommandParams)

GridCaseGroupResult = _reflection.GeneratedProtocolMessageType('GridCaseGroupResult', (_message.Message,), {
  'DESCRIPTOR' : _GRIDCASEGROUPRESULT,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.GridCaseGroupResult)
  })
_sym_db.RegisterMessage(GridCaseGroupResult)

CreateStatisticsCaseResult = _reflection.GeneratedProtocolMessageType('CreateStatisticsCaseResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTATISTICSCASERESULT,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateStatisticsCaseResult)
  })
_sym_db.RegisterMessage(CreateStatisticsCaseResult)

CreateViewResult = _reflection.GeneratedProtocolMessageType('CreateViewResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIEWRESULT,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateViewResult)
  })
_sym_db.RegisterMessage(CreateViewResult)

CreateWbsPlotResult = _reflection.GeneratedProtocolMessageType('CreateWbsPlotResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWBSPLOTRESULT,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreateWbsPlotResult)
  })
_sym_db.RegisterMessage(CreateWbsPlotResult)

ImportWellPathsResult = _reflection.GeneratedProtocolMessageType('ImportWellPathsResult', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTWELLPATHSRESULT,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ImportWellPathsResult)
  })
_sym_db.RegisterMessage(ImportWellPathsResult)

ImportWellLogFilesResult = _reflection.GeneratedProtocolMessageType('ImportWellLogFilesResult', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTWELLLOGFILESRESULT,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ImportWellLogFilesResult)
  })
_sym_db.RegisterMessage(ImportWellLogFilesResult)

ExportWellLogPlotDataResult = _reflection.GeneratedProtocolMessageType('ExportWellLogPlotDataResult', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTWELLLOGPLOTDATARESULT,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.ExportWellLogPlotDataResult)
  })
_sym_db.RegisterMessage(ExportWellLogPlotDataResult)

CommandReply = _reflection.GeneratedProtocolMessageType('CommandReply', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDREPLY,
  '__module__' : 'Commands_pb2'
  # @@protoc_insertion_point(class_scope:rips.CommandReply)
  })
_sym_db.RegisterMessage(CommandReply)



_COMMANDS = _descriptor.ServiceDescriptor(
  name='Commands',
  full_name='rips.Commands',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=7714,
  serialized_end=7778,
  methods=[
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='rips.Commands.Execute',
    index=0,
    containing_service=None,
    input_type=_COMMANDPARAMS,
    output_type=_COMMANDREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMANDS)

DESCRIPTOR.services_by_name['Commands'] = _COMMANDS

# @@protoc_insertion_point(module_scope)
